# unitorch.cli.models.xprophetnet

## XProphetNetProcessor

!!! tip
    **`core/process/xprophetnet`** is the section for configuration of XProphetNetProcessor.

::: unitorch.cli.models.xprophetnet.XProphetNetProcessor

## XProphetNetForGeneration

!!! tip
    **`core/model/generation/xprophetnet`** is the section for configuration of XProphetNetForGeneration.

::: unitorch.cli.models.xprophetnet.XProphetNetForGeneration
